@@ -190,7 +190,7 @@ from aws_cdk.aws_apigatewayv2_authorizers import HttpLambdaAuthorizer, HttpLambd
 from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
 
 # This function handles your auth logic
-# auth_handler is of type Function
+# auth_handler: lambda.Function
 
 
 authorizer = HttpLambdaAuthorizer("BooksAuthorizer", auth_handler,
@@ -214,7 +214,7 @@ API Gateway supports IAM via the included `HttpIamAuthorizer` and grant syntax:
 from aws_cdk.aws_apigatewayv2_authorizers import HttpIamAuthorizer
 from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
 
-# principal is of type AnyPrincipal
+# principal: iam.AnyPrincipal
 
 
 authorizer = HttpIamAuthorizer()
@@ -244,10 +244,10 @@ from aws_cdk.aws_apigatewayv2_authorizers import WebSocketLambdaAuthorizer
 from aws_cdk.aws_apigatewayv2_integrations import WebSocketLambdaIntegration
 
 # This function handles your auth logic
-# auth_handler is of type Function
+# auth_handler: lambda.Function
 
 # This function handles your WebSocket requests
-# handler is of type Function
+# handler: lambda.Function
 
 
 authorizer = WebSocketLambdaAuthorizer("Authorizer", auth_handler)
@@ -296,7 +296,7 @@ class HttpIamAuthorizer(
         from aws_cdk.aws_apigatewayv2_authorizers import HttpIamAuthorizer
         from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
         
-        # principal is of type AnyPrincipal
+        # principal: iam.AnyPrincipal
         
         
         authorizer = HttpIamAuthorizer()
@@ -533,7 +533,7 @@ class HttpLambdaAuthorizer(
         from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
         
         # This function handles your auth logic
-        # auth_handler is of type Function
+        # auth_handler: lambda.Function
         
         
         authorizer = HttpLambdaAuthorizer("BooksAuthorizer", auth_handler,
@@ -635,7 +635,7 @@ class HttpLambdaAuthorizerProps:
             from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
             
             # This function handles your auth logic
-            # auth_handler is of type Function
+            # auth_handler: lambda.Function
             
             
             authorizer = HttpLambdaAuthorizer("BooksAuthorizer", auth_handler,
@@ -859,7 +859,7 @@ class HttpUserPoolAuthorizerProps:
             import aws_cdk.aws_apigatewayv2_authorizers as apigatewayv2_authorizers
             import aws_cdk.aws_cognito as cognito
             
-            # user_pool_client is of type UserPoolClient
+            # user_pool_client: cognito.UserPoolClient
             
             http_user_pool_authorizer_props = apigatewayv2_authorizers.HttpUserPoolAuthorizerProps(
                 authorizer_name="authorizerName",
@@ -952,10 +952,10 @@ class WebSocketLambdaAuthorizer(
         from aws_cdk.aws_apigatewayv2_integrations import WebSocketLambdaIntegration
         
         # This function handles your auth logic
-        # auth_handler is of type Function
+        # auth_handler: lambda.Function
         
         # This function handles your WebSocket requests
-        # handler is of type Function
+        # handler: lambda.Function
         
         
         authorizer = WebSocketLambdaAuthorizer("Authorizer", auth_handler)
@@ -982,7 +982,7 @@ class WebSocketLambdaAuthorizer(
         :param id: -
         :param handler: -
         :param authorizer_name: (experimental) The name of the authorizer. Default: - same value as ``id`` passed in the constructor.
-        :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
+        :param identity_source: (experimental) The identity source for which authorization is requested. Request parameter match ``'route.request.querystring|header.[a-zA-z0-9._-]+'``. Staged variable match ``'stageVariables.[a-zA-Z0-9._-]+'``. Context parameter match ``'context.[a-zA-Z0-9._-]+'``. Default: ['route.request.header.Authorization']
 
         :stability: experimental
         '''
@@ -1031,7 +1031,7 @@ class WebSocketLambdaAuthorizerProps:
         '''(experimental) Properties to initialize WebSocketTokenAuthorizer.
 
         :param authorizer_name: (experimental) The name of the authorizer. Default: - same value as ``id`` passed in the constructor.
-        :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
+        :param identity_source: (experimental) The identity source for which authorization is requested. Request parameter match ``'route.request.querystring|header.[a-zA-z0-9._-]+'``. Staged variable match ``'stageVariables.[a-zA-Z0-9._-]+'``. Context parameter match ``'context.[a-zA-Z0-9._-]+'``. Default: ['route.request.header.Authorization']
 
         :stability: experimental
         :exampleMetadata: fixture=_generated
@@ -1068,7 +1068,11 @@ class WebSocketLambdaAuthorizerProps:
     def identity_source(self) -> typing.Optional[typing.List[builtins.str]]:
         '''(experimental) The identity source for which authorization is requested.
 
-        :default: ['$request.header.Authorization']
+        Request parameter match ``'route.request.querystring|header.[a-zA-z0-9._-]+'``.
+        Staged variable match ``'stageVariables.[a-zA-Z0-9._-]+'``.
+        Context parameter match ``'context.[a-zA-Z0-9._-]+'``.
+
+        :default: ['route.request.header.Authorization']
 
         :stability: experimental
         '''
